/*
 * To change this template, choose Tools | Templates
 * and open the template in the editor.
 */

package net.yakiboo.yakito;

import it.sauronsoftware.jave.Encoder;
import it.sauronsoftware.jave.EncoderException;

import java.io.File;
import java.util.LinkedList;
import java.util.List;

import net.yakiboo.yakito.io.YakiToFileSystem;
import net.yakiboo.yakito.io.YakiToOutput;
import net.yakiboo.yakito.io.YakiToXML;

/**
 * Clase que representa a un contenedor multimedia (o formato)
 * 
 * @author Sergio Garcia Mondaray
 */
public class YakiToContainer {

	String name, extension, definition;

	/**
	 * Constructor del contenedor multimedia
	 * 
	 * @param name
	 *            Nombre del contenedor o formato
	 * @param extension
	 *            Extension de los archivos de dicho formato
	 * @param definition
	 *            Explicacion del formato
	 */
	public YakiToContainer(String name, String extension, String definition) {
		this.name = name;
		this.extension = extension;
		this.definition = definition;
	}

	/**
	 * Constructor del contenedor multimedia
	 * 
	 * @param extension
	 *            Extension de los archivos de este formato
	 */
	public YakiToContainer(String extension) {
		this.extension = extension;
	}

	/**
	 * Obtiene el nombre del contenedor multimedia
	 * 
	 * @return Nombre del formato
	 */
	public String getName() {
		return name;
	}

	/**
	 * Obtiene la extension del contenedor multimedia
	 * 
	 * @return Extension asociada a los archivos de este formato
	 */
	public String getExtension() {
		return extension;
	}

	/**
	 * Obtiene la definicion del tipo de contenedor o formato
	 * @return
	 */
	public String getDefinition() {
		return definition;
	}

	/**
	 * Obtiene un listado de todos los contenedores multimedia soportados por YakiTo
	 * @return Lista de formatos disponibles
	 * @throws YakiToNoContainersException
	 */
	public static List<YakiToContainer> listAvailableContainers()
			throws YakiToNoContainersException {
		List<YakiToContainer> list = YakiToXML
				.parseContainersXMLFile(YakiToFileSystem.getContainersFile());
		return list;
	}

	@Override
	public String toString() {
		return name + " - " + definition;
	}

	@Override
	public boolean equals(Object o) {
		boolean thesame = o instanceof YakiToContainer;
		if (thesame) {
			thesame = ((YakiToContainer) o).getExtension().equals(
					this.getExtension());
		}
		return thesame;
	}

	/**
	 * @deprecated
	 * @return
	 */
	public static List<String> listAllContainers() {
		List<String> list = new LinkedList<String>();
		Encoder e = new Encoder();
		try {
			String[] formats = e.getSupportedEncodingFormats();
			for (int i = 0; i < formats.length; i++) {
				list.add(formats[i]);
			}
			YakiToOutput
					.message("Se ha obtenido la lista de contenedores multimedia disponibles ("
							+ formats.length + " formatos)");
		} catch (EncoderException ex) {
			YakiToOutput
					.error("No se ha podido obtener el listado de contenedores multimedia disponibles.");
		}
		return list;
	}

}
